@@ -1,8 +1,8 @@
 use serde_json::Value;
-use serde_yaml;
 use sha2::{Digest, Sha256};
 
 use std::env;
+use std::fmt;
 use std::fs;
 use std::process;
 
@@ -10,17 +10,19 @@ use std::io::prelude::*;
 use std::io::{self, Read};
 
 use colored::Colorize;
-use std::time::{Duration, Instant, SystemTime};
+use std::time::{Duration, SystemTime};
 
-use chrono::*;
-use yedb::*;
+use chrono::{DateTime, Local};
+use yedb::{Error, ErrorKind, SerializationEngine, YedbClient, ENGINE_VERSION, VERSION};
 
 use clap::Clap;
-use getch;
 
 #[macro_use]
 extern crate prettytable;
 
+#[macro_use]
+extern crate bma_benchmark;
+
 const DUMP_BUF_SIZE: usize = 32768;
 
 macro_rules! unwrap_io {
@@ -39,41 +41,42 @@ enum BenchmarkOp {
     GetCached,
 }
 
-impl BenchmarkOp {
-    pub fn to_string(&self) -> String {
-        use BenchmarkOp::*;
-        match self {
-            Set => "set",
-            Get => "get",
-            GetCached => "get(cached)",
-        }
-        .to_owned()
+impl fmt::Display for BenchmarkOp {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        write!(
+            f,
+            "{}",
+            match self {
+                BenchmarkOp::Set => "key_set",
+                BenchmarkOp::Get => "key_get",
+                BenchmarkOp::GetCached => "key_get(cached)",
+            }
+        )
     }
 }
 
-fn benchmark(db: &mut YedbClient, nt: usize) {
-    let n = 10_000;
+#[allow(clippy::cast_precision_loss)]
+#[allow(clippy::cast_possible_truncation)]
+#[allow(clippy::cast_sign_loss)]
+fn benchmark(db: &mut YedbClient, nt: u32, iterations: u32) {
     let i = db.info().unwrap();
     let old_cache_size = i.cache_size;
     db.key_delete_recursive(".benchmark").unwrap();
-    db.server_set("cache_size", Value::from(n * 4)).unwrap();
+    db.server_set("cache_size", Value::from(iterations * 4)).unwrap();
     let test_number = Value::from(777.777);
     let mut test_string = String::new();
     for _ in 0..1000 {
         test_string += "x";
     }
     let test_string = Value::from(test_string);
-    let mut test_array: Vec<f64> = Vec::new();
-    for _ in 0..100 {
-        test_array.push(777.777);
-    }
+    let test_array: Vec<f64> = vec![777.777; 100];
     let test_array = Value::from(test_array);
     let mut test_dict = serde_json::Map::new();
     for i in 0..100 {
-        test_dict.insert(format!("v{}", i), Value::from(i as f64 * 777.777));
+        test_dict.insert(format!("v{}", i), Value::from(f64::from(i) * 777.777));
     }
     let test_dict = Value::from(test_dict);
-    for bm_op in vec![BenchmarkOp::Set, BenchmarkOp::Get, BenchmarkOp::GetCached] {
+    for bm_op in [BenchmarkOp::Set, BenchmarkOp::Get, BenchmarkOp::GetCached] {
         for op in vec![
             ("number", test_number.clone()),
             ("string", test_string.clone()),
@@ -81,7 +84,7 @@ fn benchmark(db: &mut YedbClient, nt: usize) {
             ("object", test_dict.clone()),
         ] {
             let mut handlers = Vec::new();
-            let t_start = Instant::now();
+            staged_benchmark_start!(&format!("{} {}", bm_op, op.0));
             for thread_no in 0..nt {
                 let op = op.clone();
                 let op_name = op.0;
@@ -89,7 +92,7 @@ fn benchmark(db: &mut YedbClient, nt: usize) {
                 let db_path = db.path.clone();
                 let t = std::thread::spawn(move || {
                     let mut session = YedbClient::new(&db_path);
-                    for x in 0..(n / nt) {
+                    for x in 0..(iterations / nt) {
                         let key_name = format!(".benchmark/t{}/{}_{}", thread_no, &op_name, x);
                         match bm_op {
                             BenchmarkOp::Set => {
@@ -106,32 +109,20 @@ fn benchmark(db: &mut YedbClient, nt: usize) {
             for h in handlers {
                 h.join().unwrap();
             }
-            let duration = Instant::now() - t_start;
-            let op_name = format!("{}/{}", bm_op.to_string(), op.0);
-            println!(
-                "{}: {} ops/sec",
-                match bm_op {
-                    BenchmarkOp::Set => op_name.blue().bold(),
-                    _ => op_name.green().bold(),
-                },
-                (((n as f64) / (duration.as_micros() as f64 / 1_000_000f64)) as u64)
-                    .to_string()
-                    .yellow()
-            );
+            staged_benchmark_finish_current!(iterations);
         }
         if bm_op == BenchmarkOp::Set {
             db.purge_cache().unwrap();
         }
-        println!("");
     }
     let mut handlers = Vec::new();
-    let t_start = Instant::now();
+    staged_benchmark_start!("key_increment");
     for thread_no in 0..nt {
         let db_path = db.path.clone();
         let t = std::thread::spawn(move || {
             let mut session = YedbClient::new(&db_path);
             let key_name = format!(".benchmark/incr/increment_{}", thread_no);
-            for _ in 0..(n / nt) {
+            for _ in 0..(iterations / nt) {
                 session.key_increment(&key_name).unwrap();
             }
         });
@@ -140,20 +131,13 @@ fn benchmark(db: &mut YedbClient, nt: usize) {
     for h in handlers {
         h.join().unwrap();
     }
-    let duration = Instant::now() - t_start;
-    println!(
-        "{}: {} ops/sec",
-        "increment".cyan().bold(),
-        (((n as f64) / (duration.as_micros() as f64 / 1_000_000f64)) as u64)
-            .to_string()
-            .yellow()
-    );
-    db.key_delete_recursive(".benchmark").unwrap();
-    println!();
+    staged_benchmark_finish_current!(iterations);
     println!("Cleaning up...");
+    db.key_delete_recursive(".benchmark").unwrap();
     db.purge().unwrap();
     db.server_set("cache_size", Value::from(old_cache_size))
         .unwrap();
+    staged_benchmark_print!();
 }
 
 #[derive(Clap)]
@@ -251,7 +235,9 @@ struct ServerPropCommand {
 #[derive(Clap)]
 struct BenchmarkCommand {
     #[clap(long, default_value = "4")]
-    threads: usize,
+    threads: u32,
+    #[clap(long, default_value = "10000")]
+    iterations: u32,
 }
 
 #[derive(Clap)]
@@ -367,20 +353,18 @@ impl std::str::FromStr for SetType {
     type Err = Error;
 
     fn from_str(s: &str) -> Result<Self, Self::Err> {
-        use SetType::*;
         match s {
-            "number" => Ok(Num),
-            "string" => Ok(Str),
-            "boolean" => Ok(Bool),
-            "json" => Ok(Json),
-            "yaml" => Ok(Yaml),
+            "number" => Ok(SetType::Num),
+            "string" => Ok(SetType::Str),
+            "boolean" => Ok(SetType::Bool),
+            "json" => Ok(SetType::Json),
+            "yaml" => Ok(SetType::Yaml),
             _ => Err(Error::new(ErrorKind::Other, "Invalid type")),
         }
     }
 }
 
 fn format_value(value: String, p: SetType) -> Result<Value, Error> {
-    use SetType::*;
     let s = match value.as_str() {
         "-" => {
             let mut buffer = String::new();
@@ -395,24 +379,24 @@ fn format_value(value: String, p: SetType) -> Result<Value, Error> {
         _ => value,
     };
     match p {
-        Num => match s.parse::<i64>() {
+        SetType::Num => match s.parse::<i64>() {
             Ok(v) => Ok(Value::from(v)),
             Err(_) => match s.parse::<f64>() {
                 Ok(v) => Ok(Value::from(v)),
                 Err(e) => Err(Error::new(ErrorKind::Other, e)),
             },
         },
-        Str => Ok(Value::String(s)),
-        Bool => match s.as_str() {
+        SetType::Str => Ok(Value::String(s)),
+        SetType::Bool => match s.as_str() {
             "true" => Ok(Value::from(true)),
             "false" => Ok(Value::from(false)),
             _ => Err(Error::new(ErrorKind::Other, "value error")),
         },
-        Json => match serde_json::from_str(&s) {
+        SetType::Json => match serde_json::from_str(&s) {
             Ok(v) => Ok(v),
             Err(e) => Err(Error::new(ErrorKind::Other, e)),
         },
-        Yaml => match serde_yaml::from_str(&s) {
+        SetType::Yaml => match serde_yaml::from_str(&s) {
             Ok(v) => Ok(v),
             Err(e) => Err(Error::new(ErrorKind::Other, e)),
         },
@@ -477,7 +461,7 @@ fn output_value<T: std::fmt::Display>(value: T) {
 }
 
 fn output_error<T: std::fmt::Display>(err: T) {
-    eprintln!("{}", err.to_string().red())
+    eprintln!("{}", err.to_string().red());
 }
 
 macro_rules! output_editor_error {
@@ -487,17 +471,17 @@ macro_rules! output_editor_error {
     };
 }
 
-fn edit_key(db: &mut YedbClient, key: &String, value: Option<&Value>) -> i32 {
+fn edit_key(db: &mut YedbClient, key: &str, value: Option<&Value>) -> i32 {
     let mut code = 0;
     let mut hasher = Sha256::new();
     hasher.update(&key);
     let digest = hasher.finalize();
     let temp_file_name = format!(
         "{}/yedb-{}.yml",
-        env::var("TEMP").unwrap_or(env::var("TMP").unwrap_or("/tmp".to_owned())),
+        env::var("TEMP").unwrap_or_else(|_| env::var("TMP").unwrap_or_else(|_| "/tmp".to_owned())),
         hex::encode(&digest)
     );
-    let editor = env::var("EDITOR").unwrap_or("vi".to_owned());
+    let editor = env::var("EDITOR").unwrap_or_else(|_| "vi".to_owned());
     let wres = match value {
         Some(v) => fs::write(&temp_file_name, serde_yaml::to_string(&v).unwrap()),
         None => Ok(()),
@@ -510,15 +494,12 @@ fn edit_key(db: &mut YedbClient, key: &String, value: Option<&Value>) -> i32 {
                     match fs::read_to_string(&temp_file_name) {
                         Ok(content) => match serde_yaml::from_str(&content) {
                             Ok(v) => {
-                                match value {
-                                    Some(val) => {
-                                        if &v == val {
-                                            break;
-                                        }
+                                if let Some(val) = value {
+                                    if &v == val {
+                                        break;
                                     }
-                                    None => {}
                                 };
-                                match db.key_set(&key, v) {
+                                match db.key_set(key, v) {
                                     Ok(_) => {
                                         print_ok();
                                         break;
@@ -551,7 +532,7 @@ fn edit_key(db: &mut YedbClient, key: &String, value: Option<&Value>) -> i32 {
             code = 3;
         }
     }
-    let _ = fs::remove_file(&temp_file_name);
+    let _r = fs::remove_file(&temp_file_name);
     code
 }
 
@@ -567,17 +548,10 @@ macro_rules! format_bool {
     };
 }
 
-fn server_set_prop(db: &mut YedbClient, prop: &String, value: String) -> Result<(), Error> {
-    let val = match prop.as_str() {
-        "auto_flush" => format_bool!(value),
-        "repair_recommended" => format_bool!(value),
-        "cache_size" => match value.parse::<usize>() {
-            Ok(v) => Value::from(v),
-            Err(e) => {
-                return Err(Error::new(ErrorKind::Other, e));
-            }
-        },
-        "auto_bak" => match value.parse::<usize>() {
+fn server_set_prop(db: &mut YedbClient, prop: &str, value: String) -> Result<(), Error> {
+    let val = match prop {
+        "auto_flush" | "repair_recommended" => format_bool!(value),
+        "cache_size" | "auto_bak" => match value.parse::<usize>() {
             Ok(v) => Value::from(v),
             Err(e) => {
                 return Err(Error::new(ErrorKind::Other, e));
@@ -587,7 +561,7 @@ fn server_set_prop(db: &mut YedbClient, prop: &String, value: String) -> Result<
             return Err(Error::new(ErrorKind::Other, "Option not supported"));
         }
     };
-    db.server_set(&prop, val)
+    db.server_set(prop, val)
 }
 
 fn ctable(titles: Vec<&str>) -> prettytable::Table {
@@ -619,9 +593,10 @@ fn _format_debug_value(value: &Value) -> String {
             .replace("\t", " "),
         _ => value.to_string(),
     };
-    match s.len() > 79 {
-        true => s[..76].to_owned() + "...",
-        false => s,
+    if s.len() > 79 {
+        s[..76].to_owned() + "..."
+    } else {
+        s
     }
 }
 
@@ -646,19 +621,20 @@ impl DisplayVerbose for Value {
 fn display_obj(obj: &serde_json::map::Map<String, Value>) {
     let mut table = ctable(vec!["name", "value"]);
     for k in obj {
-        let value = _format_debug_value(&k.1);
+        let value = _format_debug_value(k.1);
         table.add_row(row![&k.0, value]);
     }
     table.printstd();
 }
 
-fn save_dump(db: &mut YedbClient, key: &str, file_name: &String) -> Result<usize, Error> {
+#[allow(clippy::cast_possible_truncation)]
+fn save_dump(db: &mut YedbClient, key: &str, file_name: &str) -> Result<usize, Error> {
     let key_data: Vec<(String, Value)> = db.key_dump(key)?;
     let mut f = unwrap_io!(fs::File::create(file_name));
     let mut keys_dumped = 0;
     unwrap_io!(f.write_all(&[
         ENGINE_VERSION,
-        SerializationEngine::from_str("msgpack")?.as_u8()
+        SerializationEngine::from_string("msgpack")?.as_u8()
     ]));
     for kd in key_data {
         let buf = match rmp_serde::to_vec_named(&kd) {
@@ -706,10 +682,11 @@ enum DumpLoadMode {
     ViewFull,
 }
 
-fn load_dump(db: &mut YedbClient, file_name: &String, mode: DumpLoadMode) -> Result<usize, Error> {
+#[allow(clippy::unnecessary_mut_passed)]
+fn load_dump(db: &mut YedbClient, file_name: &str, mode: DumpLoadMode) -> Result<usize, Error> {
     macro_rules! process_data_buf {
         ($c:expr, $d:expr) => {
-            if $d.len() > 0 {
+            if !$d.is_empty() {
                 $d.reverse();
                 if mode == DumpLoadMode::Load {
                     let mut data: Vec<(String, Value)> = Vec::new();
@@ -743,7 +720,7 @@ fn load_dump(db: &mut YedbClient, file_name: &String, mode: DumpLoadMode) -> Res
 
     let mut f = unwrap_io!(Reader::open(file_name));
     let mut keys_loaded = 0;
-    let mut buf = vec![0u8; 2];
+    let mut buf = vec![0_u8; 2];
     unwrap_io!(f.read_exact(&mut buf));
     if buf[0] != ENGINE_VERSION {
         return Err(Error::new(
@@ -751,19 +728,19 @@ fn load_dump(db: &mut YedbClient, file_name: &String, mode: DumpLoadMode) -> Res
             format!("Unsupported engine version: {}", buf[0]),
         ));
     }
-    if buf[1] != SerializationEngine::from_str("msgpack")?.as_u8() {
+    if buf[1] != SerializationEngine::from_string("msgpack")?.as_u8() {
         return Err(Error::new(
             ErrorKind::UnsupportedFormat,
-            format!("Unsupported dump format"),
+            "Unsupported dump format".to_owned(),
         ));
     }
     let mut data_buf: Vec<(String, Value)> = Vec::new();
     loop {
-        let mut buf = vec![0u8; 4];
+        let mut buf = vec![0_u8; 4];
         match f.read_exact(&mut buf) {
             Ok(_) => {
                 let data_len = u32::from_le_bytes([buf[0], buf[1], buf[2], buf[3]]);
-                let mut buf = vec![0u8; data_len as usize];
+                let mut buf = vec![0_u8; data_len as usize];
                 unwrap_io!(f.read_exact(&mut buf));
                 data_buf.push(match rmp_serde::from_read_ref(&buf) {
                     Ok(v) => v,
@@ -786,49 +763,35 @@ fn load_dump(db: &mut YedbClient, file_name: &String, mode: DumpLoadMode) -> Res
 
 fn format_time(obj: &mut serde_json::map::Map<String, Value>, fields: Vec<&str>) {
     for f in fields {
-        match obj.get(f) {
-            Some(val) => match val.as_u64() {
-                Some(ts_ns) => {
-                    let d: SystemTime = SystemTime::UNIX_EPOCH + Duration::from_nanos(ts_ns);
-                    let dt: DateTime<Local> = DateTime::from(d);
-                    obj.insert(f.to_owned(), Value::from(dt.to_rfc3339()));
-                }
-                None => {}
-            },
-            None => {}
-        }
+        if let Some(ts_ns) = obj.get(f).and_then(|val| Value::as_u64(val)) {
+            let d: SystemTime = SystemTime::UNIX_EPOCH + Duration::from_nanos(ts_ns);
+            let dt: DateTime<Local> = DateTime::from(d);
+            obj.insert(f.to_owned(), Value::from(dt.to_rfc3339()));
+        };
     }
 }
 
 fn convert_bool(value: Option<bool>, mode: ConvertBools) -> String {
     match mode {
-        ConvertBools::No => match value {
-            Some(v) => v.to_string(),
-            None => "null".to_owned(),
-        },
-        ConvertBools::OneZero => {
-            let val = match value {
-                Some(v) => v,
-                None => false,
-            };
-            match val {
-                true => "1".to_owned(),
-                false => "0".to_owned(),
+        ConvertBools::No => value.map_or("null".to_owned(), |v| v.to_string()),
+        ConvertBools::OneZero => value.map_or("0".to_owned(), |v| {
+            if v {
+                "1".to_owned()
+            } else {
+                "0".to_owned()
             }
-        }
-        ConvertBools::One => {
-            let val = match value {
-                Some(v) => v,
-                None => false,
-            };
-            match val {
-                true => "1".to_owned(),
-                false => "".to_owned(),
+        }),
+        ConvertBools::One => value.map_or(<_>::default(), |v| {
+            if v {
+                "1".to_owned()
+            } else {
+                <_>::default()
             }
-        }
+        }),
     }
 }
 
+#[allow(clippy::too_many_lines)]
 fn main() {
     let opts: Opts = Opts::parse();
     let mut db = YedbClient::new(&opts.path);
@@ -857,34 +820,37 @@ fn main() {
             }
         },
         Cmd::Benchmark(c) => {
-            benchmark(&mut db, c.threads);
+            benchmark(&mut db, c.threads, c.iterations);
             0
         }
         Cmd::Server(c) => output_result_ok(server_set_prop(&mut db, &c.prop, c.value)),
-        Cmd::Get(c) => match c.recursive {
-            true => match db.key_get_recursive(&c.key) {
-                Ok(v) => {
-                    let mut table = ctable(vec!["key", "type", "value"]);
-                    for key in v {
-                        let value = _format_debug_value(&key.1);
-                        table.add_row(row![&key.0, &key.1.type_as_str(), value]);
+        Cmd::Get(c) => {
+            if c.recursive {
+                match db.key_get_recursive(&c.key) {
+                    Ok(v) => {
+                        let mut table = ctable(vec!["key", "type", "value"]);
+                        for key in v {
+                            let value = _format_debug_value(&key.1);
+                            table.add_row(row![&key.0, &key.1.type_as_str(), value]);
+                        }
+                        table.printstd();
+                        0
+                    }
+                    Err(e) => {
+                        output_error(e);
+                        1
                     }
-                    table.printstd();
-                    0
                 }
-                Err(e) => {
-                    output_error(e);
-                    1
-                }
-            },
-            false => output_result_bool(
-                match c.key.find(':') {
-                    Some(pos) => db.key_get_field(&c.key[..pos], &c.key[pos + 1..]),
-                    None => db.key_get(&c.key),
-                },
-                c.convert_bool,
-            ),
-        },
+            } else {
+                output_result_bool(
+                    match c.key.find(':') {
+                        Some(pos) => db.key_get_field(&c.key[..pos], &c.key[pos + 1..]),
+                        None => db.key_get(&c.key),
+                    },
+                    c.convert_bool,
+                )
+            }
+        }
         Cmd::GetField(c) => output_result_bool(db.key_get_field(&c.key, &c.field), c.convert_bool),
         Cmd::Source(c) => {
             let result = match c.key.find(':') {
@@ -893,40 +859,34 @@ fn main() {
             };
             match result {
                 Ok(v) => {
-                    let pfx = match c.prefix {
-                        Some(v) => v + "_",
-                        None => "".to_owned(),
-                    };
-                    match v {
-                        Value::Object(o) => {
-                            for (name, value) in o {
-                                println!(
-                                    "{}{}={}",
-                                    &pfx,
-                                    name.replace("-", "_").replace(".", "_").to_uppercase(),
-                                    match value {
-                                        Value::Array(a) => {
-                                            let mut result = String::new();
-                                            for val in a {
-                                                let mut vv = val.to_string();
-                                                if vv.starts_with('"') && vv.ends_with('"') {
-                                                    vv = vv[1..vv.len() - 1].to_owned();
-                                                }
-                                                if !result.is_empty() {
-                                                    result += " ";
-                                                }
-                                                result += &vv;
+                    let pfx = c.prefix.map_or(<_>::default(), |v| v + "_");
+                    if let Value::Object(o) = v {
+                        for (name, value) in o {
+                            println!(
+                                "{}{}={}",
+                                &pfx,
+                                name.replace("-", "_").replace(".", "_").to_uppercase(),
+                                match value {
+                                    Value::Array(a) => {
+                                        let mut result = String::new();
+                                        for val in a {
+                                            let mut vv = val.to_string();
+                                            if vv.starts_with('"') && vv.ends_with('"') {
+                                                vv = vv[1..vv.len() - 1].to_owned();
                                             }
-                                            format!("\"{}\"", result)
+                                            if !result.is_empty() {
+                                                result += " ";
+                                            }
+                                            result += &vv;
                                         }
-                                        Value::Bool(b) => convert_bool(Some(b), c.convert_bool),
-                                        Value::Null => convert_bool(None, c.convert_bool),
-                                        _ => value.to_string(),
+                                        format!("\"{}\"", result)
                                     }
-                                );
-                            }
+                                    Value::Bool(b) => convert_bool(Some(b), c.convert_bool),
+                                    Value::Null => convert_bool(None, c.convert_bool),
+                                    _ => value.to_string(),
+                                }
+                            );
                         }
-                        _ => {}
                     }
                     0
                 }
@@ -937,9 +897,10 @@ fn main() {
             }
         }
         Cmd::Ls(c) => {
-            let result = match c.all {
-                true => db.key_list_all(&c.key),
-                false => db.key_list(&c.key),
+            let result = if c.all {
+                db.key_list_all(&c.key)
+            } else {
+                db.key_list(&c.key)
             };
             match result {
                 Ok(v) => {
@@ -958,10 +919,13 @@ fn main() {
         }
         Cmd::Delete(c) => match c.key.find(':') {
             Some(pos) => output_result_ok(db.key_delete_field(&c.key[..pos], &c.key[pos + 1..])),
-            None => match c.recursive {
-                true => output_result_ok(db.key_delete_recursive(&c.key)),
-                false => output_result_ok(db.key_delete(&c.key)),
-            },
+            None => {
+                if c.recursive {
+                    output_result_ok(db.key_delete_recursive(&c.key))
+                } else {
+                    output_result_ok(db.key_delete(&c.key))
+                }
+            }
         },
         Cmd::Incr(c) => output_result(db.key_increment(&c.key)),
         Cmd::Decr(c) => output_result(db.key_decrement(&c.key)),
@@ -980,14 +944,12 @@ fn main() {
         },
         Cmd::Edit(c) => match db.key_get(&c.key) {
             Ok(v) => {
-                match c.default {
-                    Some(v) if v == "-" => {
+                if let Some(v) = c.default {
+                    if v == "-" {
                         let mut buffer = String::new();
                         io::stdin().read_to_string(&mut buffer).unwrap();
                     }
-                    Some(_) => {}
-                    None => {}
-                };
+                }
                 edit_key(&mut db, &c.key, Some(&v))
             }
             Err(ref e) if e.kind() == ErrorKind::KeyNotFound => {
@@ -1037,16 +999,13 @@ fn main() {
                 for key in &keys {
                     println!("{}", format!("Key is broken: {}", key).red());
                 }
-                match keys.len() {
-                    0 => {
-                        print_ok();
-                        0
-                    }
-                    _ => {
-                        println!();
-                        println!("Run \"repair\" command to clean up and fix the database");
-                        5
-                    }
+                if keys.is_empty() {
+                    print_ok();
+                    0
+                } else {
+                    println!();
+                    println!("Run \"repair\" command to clean up and fix the database");
+                    5
                 }
             }
             Err(e) => {
@@ -1057,11 +1016,10 @@ fn main() {
         Cmd::Repair => match db.repair() {
             Ok(keys) => {
                 for key_data in keys {
-                    match key_data.1 {
-                        true => {
-                            println!("{}", format!("Key restored: {}", key_data.0).green().bold())
-                        }
-                        false => println!("{}", format!("Key removed: {}", key_data.0).red()),
+                    if key_data.1 {
+                        println!("{}", format!("Key restored: {}", key_data.0).green().bold());
+                    } else {
+                        println!("{}", format!("Key removed: {}", key_data.0).red());
                     }
                 }
                 0
@@ -1107,9 +1065,10 @@ fn main() {
             DumpCommands::View(c) => match load_dump(
                 &mut db,
                 &c.file,
-                match c.full {
-                    true => DumpLoadMode::ViewFull,
-                    false => DumpLoadMode::View,
+                if c.full {
+                    DumpLoadMode::ViewFull
+                } else {
+                    DumpLoadMode::View
                 },
             ) {
                 Ok(_) => 0,
